from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import statement_pb2 as _statement_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateStatementInput(_message.Message):
    __slots__ = ["statement"]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class CreateStatementOutput(_message.Message):
    __slots__ = ["statement_id"]
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    statement_id: str
    def __init__(self, statement_id: _Optional[str] = ...) -> None: ...

class DeleteStatementInput(_message.Message):
    __slots__ = ["statement_id"]
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    statement_id: str
    def __init__(self, statement_id: _Optional[str] = ...) -> None: ...

class DeleteStatementOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeStatementInput(_message.Message):
    __slots__ = ["render", "statement_id", "version"]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    render: bool
    statement_id: str
    version: int
    def __init__(self, statement_id: _Optional[str] = ..., render: bool = ..., version: _Optional[int] = ...) -> None: ...

class DescribeStatementOutput(_message.Message):
    __slots__ = ["statement"]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class ListStatementsInput(_message.Message):
    __slots__ = ["render", "version"]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    render: bool
    version: int
    def __init__(self, render: bool = ..., version: _Optional[int] = ...) -> None: ...

class ListStatementsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_statement_pb2.Statement]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_statement_pb2.Statement, _Mapping]]] = ...) -> None: ...

class LookupStatementInput(_message.Message):
    __slots__ = ["locale", "render", "version"]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    locale: str
    render: bool
    version: int
    def __init__(self, locale: _Optional[str] = ..., render: bool = ..., version: _Optional[int] = ...) -> None: ...

class LookupStatementOutput(_message.Message):
    __slots__ = ["statement"]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class PreviewStatementInput(_message.Message):
    __slots__ = ["statement"]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class PreviewStatementOutput(_message.Message):
    __slots__ = ["statement"]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class StatementChangedEvent(_message.Message):
    __slots__ = ["after", "before", "problem_id"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    after: _statement_pb2.Statement
    before: _statement_pb2.Statement
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ..., before: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ..., after: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class UpdateStatementInput(_message.Message):
    __slots__ = ["patch", "statement", "statement_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateStatementInput.Patch
    AUTHOR: UpdateStatementInput.Patch
    CONTENT: UpdateStatementInput.Patch
    DOWNLOAD_LINK: UpdateStatementInput.Patch
    LOCALE: UpdateStatementInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SOURCE: UpdateStatementInput.Patch
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TITLE: UpdateStatementInput.Patch
    patch: _containers.RepeatedScalarFieldContainer[UpdateStatementInput.Patch]
    statement: _statement_pb2.Statement
    statement_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateStatementInput.Patch, str]]] = ..., statement_id: _Optional[str] = ..., statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class UpdateStatementOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ClassServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateClass(self, request, **kwargs):
        path = "/classes"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.CreateClassOutput"),
            **kwargs,
        )

    def UpdateClass(self, request, **kwargs):
        path = "/classes/"+urllib.parse.quote(request.group_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.group_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.UpdateClassOutput"),
            **kwargs,
        )

    def DeleteClass(self, request, **kwargs):
        path = "/classes/"+urllib.parse.quote(request.group_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.group_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DeleteClassOutput"),
            **kwargs,
        )

    def DescribeClass(self, request, **kwargs):
        path = "/classes/"+urllib.parse.quote(request.group_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.group_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DescribeClassOutput"),
            **kwargs,
        )

    def ListClasses(self, request, **kwargs):
        path = "/classes"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListClassesOutput"),
            **kwargs,
        )

    def ListClassAssignments(self, request, **kwargs):
        path = "/classes/"+urllib.parse.quote(request.group_id)+"/assignments"

        # Cleanup URL parameters to avoid any ambiguity
        request.group_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListClassAssignmentsOutput"),
            **kwargs,
        )

    def UpdateClassAssignment(self, request, **kwargs):
        path = "/classes/"+urllib.parse.quote(request.group_id)+"/assignments"

        # Cleanup URL parameters to avoid any ambiguity
        request.group_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.UpdateClassAssignmentOutput"),
            **kwargs,
        )

    def DeleteClassAssignment(self, request, **kwargs):
        path = "/classes/"+urllib.parse.quote(request.group_id)+"/assignments"

        # Cleanup URL parameters to avoid any ambiguity
        request.group_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DeleteClassAssignmentOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/billing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import address_pb2 as eolymp_dot_commerce_dot_address__pb2
from eolymp.universe import plan_pb2 as eolymp_dot_universe_dot_plan__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/universe/billing.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/commerce/address.proto\x1a\x1a\x65olymp/universe/plan.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdd\x07\n\x07\x42illing\x1a\xb3\x01\n\x0bInformation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\x13\n\x0btax_id_type\x18\n \x01(\t\x12\x14\n\x0ctax_id_value\x18\x0b \x01(\t\x12)\n\x07\x61\x64\x64ress\x18\x14 \x01(\x0b\x32\x18.eolymp.commerce.Address\x12\x10\n\x08\x63urrency\x18Z \x01(\t\x12\x10\n\x08language\x18[ \x01(\t\x1a\x98\x05\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.eolymp.universe.Billing.Status\x12\x11\n\tirregular\x18\x03 \x01(\x08\x12\x1a\n\x12has_payment_method\x18\x04 \x01(\x08\x12#\n\x04plan\x18\n \x01(\x0b\x32\x15.eolymp.universe.Plan\x12.\n\x07variant\x18\x0b \x01(\x0b\x32\x1d.eolymp.universe.Plan.Variant\x12\r\n\x05seats\x18\x0c \x01(\r\x12/\n\ncreated_at\x18\xd2\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\nstarted_at\x18\xd3\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\tcancel_at\x18\xd5\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x0c\x63\x61ncelled_at\x18\xd6\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x08\x65nded_at\x18\xd7\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x0cperiod_start\x18\xf0\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\nperiod_end\x18\xf1\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0btrial_start\x18\x8e\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ttrial_end\x18\x8f\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"B\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\t\n\x05TRIAL\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tCANCELLED\x10\x03\"=\n\nRecurrence\x12\x16\n\x12UNKNOWN_RECURRENCE\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\n\n\x06YEARLY\x10\x02\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.billing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _BILLING._serialized_start=143
  _BILLING._serialized_end=1132
  _BILLING_INFORMATION._serialized_start=155
  _BILLING_INFORMATION._serialized_end=334
  _BILLING_SUBSCRIPTION._serialized_start=337
  _BILLING_SUBSCRIPTION._serialized_end=1001
  _BILLING_STATUS._serialized_start=1003
  _BILLING_STATUS._serialized_end=1069
  _BILLING_RECURRENCE._serialized_start=1071
  _BILLING_RECURRENCE._serialized_end=1132
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.judge import announcement_service_pb2 as _announcement_service_pb2
from eolymp.judge import contest_service_pb2 as _contest_service_pb2
from eolymp.judge import participant_service_pb2 as _participant_service_pb2
from eolymp.judge import passcode_service_pb2 as _passcode_service_pb2
from eolymp.judge import problem_service_pb2 as _problem_service_pb2
from eolymp.judge import score_service_pb2 as _score_service_pb2
from eolymp.judge import submission_service_pb2 as _submission_service_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testing_checker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import checker_pb2 as eolymp_dot_executor_dot_checker__pb2
from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_checker.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/executor/checker.proto\x1a\x1a\x65olymp/executor/file.proto\"\xd1\x01\n\x07\x43hecker\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.eolymp.executor.Checker.Type\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x11\n\tprecision\x18\x04 \x01(\x05\x12\x16\n\x0e\x63\x61se_sensitive\x18\x05 \x01(\x08\x12\x17\n\x0forder_sensitive\x18\x06 \x01(\x08\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12$\n\x05\x66iles\x18\n \x03(\x0b\x32\x15.eolymp.executor.FileB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_checker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CHECKER._serialized_start=112
  _CHECKER._serialized_end=321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/student.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/course/student.proto\x12\reolymp.course\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x03\n\x07Student\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x10\n\x08inactive\x18\x04 \x01(\x08\x12\x12\n\nassign_all\x18\x05 \x01(\x08\x12\x18\n\x10overall_progress\x18\n \x01(\x02\x12\x15\n\roverall_grade\x18\x0f \x01(\r\x12,\n\x06grades\x18\x14 \x03(\x0b\x32\x1c.eolymp.course.Student.Grade\x12-\n\tgraded_at\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x63ursor\x18\x64 \x01(\t\x1ak\n\x05Grade\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\r\n\x05grade\x18\n \x01(\r\x12\x17\n\x0fgrade_automatic\x18\x0b \x01(\r\x12\x16\n\x0egrade_override\x18\x0c \x01(\r\x12\x0f\n\x07\x65xcused\x18\x03 \x01(\x08\"&\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\n\n\x06GRADES\x10\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.student_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _STUDENT._serialized_start=80
  _STUDENT._serialized_end=574
  _STUDENT_GRADE._serialized_start=427
  _STUDENT_GRADE._serialized_end=534
  _STUDENT_EXTRA._serialized_start=536
  _STUDENT_EXTRA._serialized_end=574
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Notification(_message.Message):
    __slots__ = ["created_at", "id", "parameters", "read", "read_at", "sent_at", "topic"]
    class ParametersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    READ_AT_FIELD_NUMBER: _ClassVar[int]
    READ_FIELD_NUMBER: _ClassVar[int]
    SENT_AT_FIELD_NUMBER: _ClassVar[int]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    created_at: _timestamp_pb2.Timestamp
    id: str
    parameters: _containers.ScalarMap[str, str]
    read: bool
    read_at: _timestamp_pb2.Timestamp
    sent_at: _timestamp_pb2.Timestamp
    topic: str
    def __init__(self, id: _Optional[str] = ..., read: bool = ..., topic: _Optional[str] = ..., parameters: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., sent_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., read_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from eolymp.discussion import message_pb2 as _message_pb2
from eolymp.discussion import post_pb2 as _post_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _message_pb2.Message
    before: _message_pb2.Message
    def __init__(self, before: _Optional[_Union[_message_pb2.Message, _Mapping]] = ..., after: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...) -> None: ...

class PostChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _post_pb2.Post
    before: _post_pb2.Post
    def __init__(self, before: _Optional[_Union[_post_pb2.Post, _Mapping]] = ..., after: _Optional[_Union[_post_pb2.Post, _Mapping]] = ...) -> None: ...

class PostTranslationChangedEvent(_message.Message):
    __slots__ = ["after", "before", "post"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    POST_FIELD_NUMBER: _ClassVar[int]
    after: _post_pb2.Post.Translation
    before: _post_pb2.Post.Translation
    post: _post_pb2.Post
    def __init__(self, post: _Optional[_Union[_post_pb2.Post, _Mapping]] = ..., before: _Optional[_Union[_post_pb2.Post.Translation, _Mapping]] = ..., after: _Optional[_Union[_post_pb2.Post.Translation, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.cognito import access_key_service_pb2 as _access_key_service_pb2
from eolymp.cognito import user_service_pb2 as _user_service_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.cognito import quota_pb2 as _quota_pb2
from eolymp.cognito import user_pb2 as _user_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompleteRecoverInput(_message.Message):
    __slots__ = ["password", "secret", "user_id"]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    password: str
    secret: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., secret: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class CompleteRecoverOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateUserInput(_message.Message):
    __slots__ = ["birthday", "captcha", "country", "email", "full_name", "locale", "password", "username"]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    CAPTCHA_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    birthday: str
    captcha: str
    country: str
    email: str
    full_name: str
    locale: str
    password: str
    username: str
    def __init__(self, username: _Optional[str] = ..., full_name: _Optional[str] = ..., email: _Optional[str] = ..., password: _Optional[str] = ..., country: _Optional[str] = ..., birthday: _Optional[str] = ..., captcha: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class CreateUserOutput(_message.Message):
    __slots__ = ["email_confirmation_hint", "user_id"]
    EMAIL_CONFIRMATION_HINT_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    email_confirmation_hint: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., email_confirmation_hint: _Optional[str] = ...) -> None: ...

class DescribeUserInput(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class DescribeUserOutput(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _user_pb2.User
    def __init__(self, user: _Optional[_Union[_user_pb2.User, _Mapping]] = ...) -> None: ...

class IntrospectQuotaInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectQuotaOutput(_message.Message):
    __slots__ = ["contests_per_user", "participants_per_contest", "problems_per_contest", "problems_per_user"]
    CONTESTS_PER_USER_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_USER_FIELD_NUMBER: _ClassVar[int]
    contests_per_user: _quota_pb2.Quota
    participants_per_contest: _quota_pb2.Quota
    problems_per_contest: _quota_pb2.Quota
    problems_per_user: _quota_pb2.Quota
    def __init__(self, contests_per_user: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., problems_per_contest: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., participants_per_contest: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., problems_per_user: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ...) -> None: ...

class IntrospectUserInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectUserOutput(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _user_pb2.User
    def __init__(self, user: _Optional[_Union[_user_pb2.User, _Mapping]] = ...) -> None: ...

class ListUsersInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "username"]
        ID_FIELD_NUMBER: _ClassVar[int]
        USERNAME_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        username: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., username: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListUsersInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListUsersInput.Filter, _Mapping]] = ...) -> None: ...

class ListUsersOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_user_pb2.User]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_user_pb2.User, _Mapping]]] = ...) -> None: ...

class ResendEmailVerificationInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ResendEmailVerificationOutput(_message.Message):
    __slots__ = ["email_confirmation_hint"]
    EMAIL_CONFIRMATION_HINT_FIELD_NUMBER: _ClassVar[int]
    email_confirmation_hint: str
    def __init__(self, email_confirmation_hint: _Optional[str] = ...) -> None: ...

class SelfDestructInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SelfDestructOutput(_message.Message):
    __slots__ = ["delete_on"]
    DELETE_ON_FIELD_NUMBER: _ClassVar[int]
    delete_on: _timestamp_pb2.Timestamp
    def __init__(self, delete_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class StartRecoveryInput(_message.Message):
    __slots__ = ["captcha", "email", "locale"]
    CAPTCHA_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    captcha: str
    email: str
    locale: str
    def __init__(self, email: _Optional[str] = ..., captcha: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class StartRecoveryOutput(_message.Message):
    __slots__ = ["email_recovery_hint"]
    EMAIL_RECOVERY_HINT_FIELD_NUMBER: _ClassVar[int]
    email_recovery_hint: str
    def __init__(self, email_recovery_hint: _Optional[str] = ...) -> None: ...

class UpdatePasswordInput(_message.Message):
    __slots__ = ["current_password", "new_password"]
    CURRENT_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    NEW_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    current_password: str
    new_password: str
    def __init__(self, current_password: _Optional[str] = ..., new_password: _Optional[str] = ...) -> None: ...

class UpdatePasswordOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdatePictureInput(_message.Message):
    __slots__ = ["data", "filename", "offset_x", "offset_y", "size"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    OFFSET_X_FIELD_NUMBER: _ClassVar[int]
    OFFSET_Y_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    filename: str
    offset_x: int
    offset_y: int
    size: int
    def __init__(self, filename: _Optional[str] = ..., data: _Optional[bytes] = ..., offset_x: _Optional[int] = ..., offset_y: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class UpdatePictureOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateProfileInput(_message.Message):
    __slots__ = ["birthday", "city", "company", "country", "email", "locale", "name", "occupation", "patch", "username"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    BIRTHDAY: UpdateProfileInput.Patch
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    CITY: UpdateProfileInput.Patch
    CITY_FIELD_NUMBER: _ClassVar[int]
    COMPANY: UpdateProfileInput.Patch
    COMPANY_FIELD_NUMBER: _ClassVar[int]
    COUNTRY: UpdateProfileInput.Patch
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    EMAIL: UpdateProfileInput.Patch
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    LOCALE: UpdateProfileInput.Patch
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    NAME: UpdateProfileInput.Patch
    NAME_FIELD_NUMBER: _ClassVar[int]
    OCCUPATION: UpdateProfileInput.Patch
    OCCUPATION_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    USERNAME: UpdateProfileInput.Patch
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    birthday: str
    city: str
    company: str
    country: str
    email: str
    locale: str
    name: str
    occupation: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateProfileInput.Patch]
    username: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateProfileInput.Patch, str]]] = ..., username: _Optional[str] = ..., email: _Optional[str] = ..., name: _Optional[str] = ..., company: _Optional[str] = ..., occupation: _Optional[str] = ..., country: _Optional[str] = ..., city: _Optional[str] = ..., birthday: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class UpdateProfileOutput(_message.Message):
    __slots__ = ["email_confirmation_hint"]
    EMAIL_CONFIRMATION_HINT_FIELD_NUMBER: _ClassVar[int]
    email_confirmation_hint: str
    def __init__(self, email_confirmation_hint: _Optional[str] = ...) -> None: ...

class UserChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _user_pb2.User
    before: _user_pb2.User
    def __init__(self, before: _Optional[_Union[_user_pb2.User, _Mapping]] = ..., after: _Optional[_Union[_user_pb2.User, _Mapping]] = ...) -> None: ...

class VerifyEmailInput(_message.Message):
    __slots__ = ["secret", "user_id"]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    secret: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., secret: _Optional[str] = ...) -> None: ...

class VerifyEmailOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.helpdesk import ticket_pb2 as eolymp_dot_helpdesk_dot_ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/helpdesk/events.proto\x12\x0f\x65olymp.helpdesk\x1a\x1c\x65olymp/helpdesk/ticket.proto\"e\n\x12TicketChangedEvent\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\"\x89\x01\n\x13\x43ommentChangedEvent\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12/\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\x12.\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.CommentB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _TICKETCHANGEDEVENT._serialized_start=79
  _TICKETCHANGEDEVENT._serialized_end=180
  _COMMENTCHANGEDEVENT._serialized_start=183
  _COMMENTCHANGEDEVENT._serialized_end=320
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/code_template_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import code_template_pb2 as eolymp_dot_atlas_dot_code__template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/atlas/code_template_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/atlas/code_template.proto\"C\n\x17\x43reateCodeTemplateInput\x12(\n\x08template\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\"/\n\x18\x43reateCodeTemplateOutput\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"\xb2\x01\n\x17UpdateCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\x12(\n\x08template\x18\x03 \x01(\x0b\x32\x16.eolymp.atlas.Template\"X\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07RUNTIME\x10\x01\x12\n\n\x06SOURCE\x10\x02\x12\n\n\x06HEADER\x10\x03\x12\n\n\x06\x46OOTER\x10\x04\x12\n\n\x06SECRET\x10\x05\x12\t\n\x05\x46ILES\x10\x06\"\x1a\n\x18UpdateCodeTemplateOutput\".\n\x17\x44\x65leteCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteCodeTemplateOutput\")\n\x16ListCodeTemplatesInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"O\n\x17ListCodeTemplatesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.atlas.Template\"A\n\x19\x44\x65scribeCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"F\n\x1a\x44\x65scribeCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\"*\n\x17LookupCodeTemplateInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template2\x96\x08\n\x13\x43odeTemplateService\x12\xa1\x01\n\x12\x43reateCodeTemplate\x12%.eolymp.atlas.CreateCodeTemplateInput\x1a&.eolymp.atlas.CreateCodeTemplateOutput\"<\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0c\"\n/templates\x12\xaf\x01\n\x12UpdateCodeTemplate\x12%.eolymp.atlas.UpdateCodeTemplateInput\x1a&.eolymp.atlas.UpdateCodeTemplateOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\"\x18/templates/{template_id}\x12\xaf\x01\n\x12\x44\x65leteCodeTemplate\x12%.eolymp.atlas.DeleteCodeTemplateInput\x1a&.eolymp.atlas.DeleteCodeTemplateOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a*\x18/templates/{template_id}\x12\x9d\x01\n\x11ListCodeTemplates\x12$.eolymp.atlas.ListCodeTemplatesInput\x1a%.eolymp.atlas.ListCodeTemplatesOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/templates\x12\xb4\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.atlas.DescribeCodeTemplateInput\x1a(.eolymp.atlas.DescribeCodeTemplateOutput\"I\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x12\x18/templates/{template_id}\x12\x9f\x01\n\x12LookupCodeTemplate\x12%.eolymp.atlas.LookupCodeTemplateInput\x1a&.eolymp.atlas.LookupCodeTemplateOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\x12\t/templateB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.code_template_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CODETEMPLATESERVICE.methods_by_name['CreateCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['CreateCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\014\"\n/templates'
  _CODETEMPLATESERVICE.methods_by_name['UpdateCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['UpdateCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\032\"\030/templates/{template_id}'
  _CODETEMPLATESERVICE.methods_by_name['DeleteCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['DeleteCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\032*\030/templates/{template_id}'
  _CODETEMPLATESERVICE.methods_by_name['ListCodeTemplates']._options = None
  _CODETEMPLATESERVICE.methods_by_name['ListCodeTemplates']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/templates'
  _CODETEMPLATESERVICE.methods_by_name['DescribeCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\032\022\030/templates/{template_id}'
  _CODETEMPLATESERVICE.methods_by_name['LookupCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\013\022\t/template'
  _CREATECODETEMPLATEINPUT._serialized_start=191
  _CREATECODETEMPLATEINPUT._serialized_end=258
  _CREATECODETEMPLATEOUTPUT._serialized_start=260
  _CREATECODETEMPLATEOUTPUT._serialized_end=307
  _UPDATECODETEMPLATEINPUT._serialized_start=310
  _UPDATECODETEMPLATEINPUT._serialized_end=488
  _UPDATECODETEMPLATEINPUT_PATCH._serialized_start=400
  _UPDATECODETEMPLATEINPUT_PATCH._serialized_end=488
  _UPDATECODETEMPLATEOUTPUT._serialized_start=490
  _UPDATECODETEMPLATEOUTPUT._serialized_end=516
  _DELETECODETEMPLATEINPUT._serialized_start=518
  _DELETECODETEMPLATEINPUT._serialized_end=564
  _DELETECODETEMPLATEOUTPUT._serialized_start=566
  _DELETECODETEMPLATEOUTPUT._serialized_end=592
  _LISTCODETEMPLATESINPUT._serialized_start=594
  _LISTCODETEMPLATESINPUT._serialized_end=635
  _LISTCODETEMPLATESOUTPUT._serialized_start=637
  _LISTCODETEMPLATESOUTPUT._serialized_end=716
  _DESCRIBECODETEMPLATEINPUT._serialized_start=718
  _DESCRIBECODETEMPLATEINPUT._serialized_end=783
  _DESCRIBECODETEMPLATEOUTPUT._serialized_start=785
  _DESCRIBECODETEMPLATEOUTPUT._serialized_end=855
  _LOOKUPCODETEMPLATEINPUT._serialized_start=857
  _LOOKUPCODETEMPLATEINPUT._serialized_end=899
  _LOOKUPCODETEMPLATEOUTPUT._serialized_start=901
  _LOOKUPCODETEMPLATEOUTPUT._serialized_end=969
  _CODETEMPLATESERVICE._serialized_start=972
  _CODETEMPLATESERVICE._serialized_end=2018
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/newsletter/recipient_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.newsletter import recipient_pb2 as eolymp_dot_newsletter_dot_recipient__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/newsletter/recipient_service.proto\x12\x11\x65olymp.newsletter\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/newsletter/recipient.proto\"G\n\x14\x43reateRecipientInput\x12/\n\trecipient\x18\n \x01(\x0b\x32\x1c.eolymp.newsletter.Recipient\"-\n\x15\x43reateRecipientOutput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"5\n\x15ImportRecipientsInput\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x42\x08\n\x06source\"0\n\x16ImportRecipientsOutput\x12\x16\n\x0eimported_total\x18\x01 \x01(\t\",\n\x14RemoveRecipientInput\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x17\n\x15RemoveRecipientOutput\"3\n\x13ListRecipientsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"R\n\x14ListRecipientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.newsletter.Recipient\".\n\x16\x44\x65scribeRecipientInput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"J\n\x17\x44\x65scribeRecipientOutput\x12/\n\trecipient\x18\x01 \x01(\x0b\x32\x1c.eolymp.newsletter.Recipient2\xa4\x07\n\x10RecipientService\x12\xc0\x01\n\x11\x44\x65scribeRecipient\x12).eolymp.newsletter.DescribeRecipientInput\x1a*.eolymp.newsletter.DescribeRecipientOutput\"T\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1c\x12\x1a/recipients/{recipient_id}\x12\xb6\x01\n\x10ImportRecipients\x12(.eolymp.newsletter.ImportRecipientsInput\x1a).eolymp.newsletter.ImportRecipientsOutput\"M\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x15\"\x13/imports/recipients\x12\xa8\x01\n\x0eListRecipients\x12&.eolymp.newsletter.ListRecipientsInput\x1a\'.eolymp.newsletter.ListRecipientsOutput\"E\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/recipients\x12\xab\x01\n\x0f\x43reateRecipient\x12\'.eolymp.newsletter.CreateRecipientInput\x1a(.eolymp.newsletter.CreateRecipientOutput\"E\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\"\x0b/recipients\x12\xba\x01\n\x0fRemoveRecipient\x12\'.eolymp.newsletter.RemoveRecipientInput\x1a(.eolymp.newsletter.RemoveRecipientOutput\"T\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1c*\x1a/recipients/{recipient_id}B7Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.recipient_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _RECIPIENTSERVICE.methods_by_name['DescribeRecipient']._options = None
  _RECIPIENTSERVICE.methods_by_name['DescribeRecipient']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\034\022\032/recipients/{recipient_id}'
  _RECIPIENTSERVICE.methods_by_name['ImportRecipients']._options = None
  _RECIPIENTSERVICE.methods_by_name['ImportRecipients']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\025\"\023/imports/recipients'
  _RECIPIENTSERVICE.methods_by_name['ListRecipients']._options = None
  _RECIPIENTSERVICE.methods_by_name['ListRecipients']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\r\022\013/recipients'
  _RECIPIENTSERVICE.methods_by_name['CreateRecipient']._options = None
  _RECIPIENTSERVICE.methods_by_name['CreateRecipient']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\r\"\013/recipients'
  _RECIPIENTSERVICE.methods_by_name['RemoveRecipient']._options = None
  _RECIPIENTSERVICE.methods_by_name['RemoveRecipient']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\034*\032/recipients/{recipient_id}'
  _CREATERECIPIENTINPUT._serialized_start=198
  _CREATERECIPIENTINPUT._serialized_end=269
  _CREATERECIPIENTOUTPUT._serialized_start=271
  _CREATERECIPIENTOUTPUT._serialized_end=316
  _IMPORTRECIPIENTSINPUT._serialized_start=318
  _IMPORTRECIPIENTSINPUT._serialized_end=371
  _IMPORTRECIPIENTSOUTPUT._serialized_start=373
  _IMPORTRECIPIENTSOUTPUT._serialized_end=421
  _REMOVERECIPIENTINPUT._serialized_start=423
  _REMOVERECIPIENTINPUT._serialized_end=467
  _REMOVERECIPIENTOUTPUT._serialized_start=469
  _REMOVERECIPIENTOUTPUT._serialized_end=492
  _LISTRECIPIENTSINPUT._serialized_start=494
  _LISTRECIPIENTSINPUT._serialized_end=545
  _LISTRECIPIENTSOUTPUT._serialized_start=547
  _LISTRECIPIENTSOUTPUT._serialized_end=629
  _DESCRIBERECIPIENTINPUT._serialized_start=631
  _DESCRIBERECIPIENTINPUT._serialized_end=677
  _DESCRIBERECIPIENTOUTPUT._serialized_start=679
  _DESCRIBERECIPIENTOUTPUT._serialized_end=753
  _RECIPIENTSERVICE._serialized_start=756
  _RECIPIENTSERVICE._serialized_end=1688
# @@protoc_insertion_point(module_scope)



from eolymp.executor import stats_pb2 as _stats_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EvaluationReport(_message.Message):
    __slots__ = ["agent", "error", "failure", "origin", "reference", "runs", "signature", "task_id", "type", "version"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Run(_message.Message):
        __slots__ = ["answer_url", "checker_stats", "cost", "cpu_time_limit", "cpu_time_usage", "debug_stats", "input_url", "interactor_stats", "memory_limit", "memory_usage", "output_url", "reference", "score", "status", "wall_time_limit", "wall_time_usage"]
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ACCEPTED: EvaluationReport.Run.Status
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        CHECKER_STATS_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        CPU_EXHAUSTED: EvaluationReport.Run.Status
        CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        DEBUG_STATS_FIELD_NUMBER: _ClassVar[int]
        EXECUTED: EvaluationReport.Run.Status
        EXECUTING: EvaluationReport.Run.Status
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        INTERACTION_FAILURE: EvaluationReport.Run.Status
        INTERACTOR_STATS_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
        MEMORY_OVERFLOW: EvaluationReport.Run.Status
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        NONE: EvaluationReport.Run.Status
        OUTPUT_URL_FIELD_NUMBER: _ClassVar[int]
        PENDING: EvaluationReport.Run.Status
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_ERROR: EvaluationReport.Run.Status
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SKIPPED: EvaluationReport.Run.Status
        STATUS_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT: EvaluationReport.Run.Status
        VERIFICATION_FAILURE: EvaluationReport.Run.Status
        WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        WRONG_ANSWER: EvaluationReport.Run.Status
        answer_url: str
        checker_stats: _stats_pb2.Stats
        cost: float
        cpu_time_limit: int
        cpu_time_usage: int
        debug_stats: _stats_pb2.Stats
        input_url: str
        interactor_stats: _stats_pb2.Stats
        memory_limit: int
        memory_usage: int
        output_url: str
        reference: str
        score: float
        status: EvaluationReport.Run.Status
        wall_time_limit: int
        wall_time_usage: int
        def __init__(self, reference: _Optional[str] = ..., status: _Optional[_Union[EvaluationReport.Run.Status, str]] = ..., score: _Optional[float] = ..., cost: _Optional[float] = ..., wall_time_usage: _Optional[int] = ..., wall_time_limit: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_usage: _Optional[int] = ..., memory_limit: _Optional[int] = ..., input_url: _Optional[str] = ..., output_url: _Optional[str] = ..., answer_url: _Optional[str] = ..., debug_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ..., checker_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ..., interactor_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ...) -> None: ...
    AGENT_FIELD_NUMBER: _ClassVar[int]
    ERROR: EvaluationReport.Type
    ERROR_FIELD_NUMBER: _ClassVar[int]
    FAILURE: EvaluationReport.Type
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    NONE: EvaluationReport.Type
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UPDATE: EvaluationReport.Type
    VERSION_FIELD_NUMBER: _ClassVar[int]
    agent: str
    error: str
    failure: str
    origin: str
    reference: str
    runs: _containers.RepeatedCompositeFieldContainer[EvaluationReport.Run]
    signature: str
    task_id: str
    type: EvaluationReport.Type
    version: int
    def __init__(self, task_id: _Optional[str] = ..., reference: _Optional[str] = ..., origin: _Optional[str] = ..., agent: _Optional[str] = ..., signature: _Optional[str] = ..., version: _Optional[int] = ..., type: _Optional[_Union[EvaluationReport.Type, str]] = ..., error: _Optional[str] = ..., failure: _Optional[str] = ..., runs: _Optional[_Iterable[_Union[EvaluationReport.Run, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.cognito import quota_pb2 as eolymp_dot_cognito_dot_quota__pb2
from eolymp.cognito import user_pb2 as eolymp_dot_cognito_dot_user__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/cognito/user_service.proto\x12\x0e\x65olymp.cognito\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/cognito/quota.proto\x1a\x19\x65olymp/cognito/user.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"]\n\x10UserChangedEvent\x12$\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\x12#\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x14.eolymp.cognito.User\"\x9b\x01\n\x0f\x43reateUserInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x10\n\x08\x62irthday\x18\x06 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"D\n\x10\x43reateUserOutput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"3\n\x10VerifyEmailInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x13\n\x11VerifyEmailOutput\"\x1e\n\x1cResendEmailVerificationInput\"@\n\x1dResendEmailVerificationOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"\xdc\x02\n\x12UpdateProfileInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.cognito.UpdateProfileInput.Patch\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x0e\n\x06locale\x18\" \x01(\t\"x\n\x05Patch\x12\x0c\n\x08USERNAME\x10\x00\x12\t\n\x05\x45MAIL\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0b\n\x07\x43OMPANY\x10\x03\x12\x0e\n\nOCCUPATION\x10\x04\x12\x0b\n\x07\x43OUNTRY\x10\x05\x12\x08\n\x04\x43ITY\x10\x06\x12\x0c\n\x08\x42IRTHDAY\x10\x07\x12\n\n\x06LOCALE\x10\x08\"6\n\x13UpdateProfileOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"f\n\x12UpdatePictureInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08offset_x\x18\n \x01(\r\x12\x10\n\x08offset_y\x18\x0b \x01(\r\x12\x0c\n\x04size\x18\x0c \x01(\r\"\x15\n\x13UpdatePictureOutput\"E\n\x13UpdatePasswordInput\x12\x18\n\x10\x63urrent_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"\x16\n\x14UpdatePasswordOutput\"\x15\n\x13IntrospectUserInput\":\n\x14IntrospectUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"$\n\x11\x44\x65scribeUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"8\n\x12\x44\x65scribeUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"\xd2\x01\n\x0eListUsersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.cognito.ListUsersInput.Filter\x1aj\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x08username\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"E\n\x0fListUsersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.cognito.User\"\x16\n\x14IntrospectQuotaInput\"\xe9\x01\n\x15IntrospectQuotaOutput\x12\x30\n\x11\x63ontests_per_user\x18\n \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x33\n\x14problems_per_contest\x18\x0b \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x37\n\x18participants_per_contest\x18\x0c \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x30\n\x11problems_per_user\x18\x14 \x01(\x0b\x32\x15.eolymp.cognito.Quota\"D\n\x12StartRecoveryInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"2\n\x13StartRecoveryOutput\x12\x1b\n\x13\x65mail_recovery_hint\x18\x01 \x01(\t\"I\n\x14\x43ompleteRecoverInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x17\n\x15\x43ompleteRecoverOutput\"\x13\n\x11SelfDestructInput\"C\n\x12SelfDestructOutput\x12-\n\tdelete_on\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xf1\r\n\x0bUserService\x12n\n\nCreateUser\x12\x1f.eolymp.cognito.CreateUserInput\x1a .eolymp.cognito.CreateUserOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x08\"\x06/users\x12\x82\x01\n\x0bVerifyEmail\x12 .eolymp.cognito.VerifyEmailInput\x1a!.eolymp.cognito.VerifyEmailOutput\".\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\x19\"\x17/users/{user_id}/verify\x12\xae\x01\n\x17ResendEmailVerification\x12,.eolymp.cognito.ResendEmailVerificationInput\x1a-.eolymp.cognito.ResendEmailVerificationOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!\"\x1f/self/email/resend-verification\x12v\n\rUpdateProfile\x12\".eolymp.cognito.UpdateProfileInput\x1a#.eolymp.cognito.UpdateProfileOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/self\x12~\n\rUpdatePicture\x12\".eolymp.cognito.UpdatePictureInput\x1a#.eolymp.cognito.UpdatePictureOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0f\"\r/self/picture\x12\x98\x01\n\x0eUpdatePassword\x12#.eolymp.cognito.UpdatePasswordInput\x1a$.eolymp.cognito.UpdatePasswordOutput\";\x82\xe3\n\x12\x8a\xe3\n\x0epassword_grant\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/password\x12y\n\x0eIntrospectUser\x12#.eolymp.cognito.IntrospectUserInput\x1a$.eolymp.cognito.IntrospectUserOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x07\x12\x05/self\x12\x98\x01\n\x0c\x44\x65scribeUser\x12!.eolymp.cognito.DescribeUserInput\x1a\".eolymp.cognito.DescribeUserOutput\"A\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HC\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x12\x12\x10/users/{user_id}\x12\x84\x01\n\tListUsers\x12\x1e.eolymp.cognito.ListUsersInput\x1a\x1f.eolymp.cognito.ListUsersOutput\"6\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00pA\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/users\x12\x82\x01\n\x0fIntrospectQuota\x12$.eolymp.cognito.IntrospectQuotaInput\x1a%.eolymp.cognito.IntrospectQuotaOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/self/quota\x12\x7f\n\rStartRecovery\x12\".eolymp.cognito.StartRecoveryInput\x1a#.eolymp.cognito.StartRecoveryOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/recovery\x12\x90\x01\n\x10\x43ompleteRecovery\x12$.eolymp.cognito.CompleteRecoverInput\x1a%.eolymp.cognito.CompleteRecoverOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1a\"\x18/users/{user_id}/recover\x12s\n\x0cSelfDestruct\x12!.eolymp.cognito.SelfDestructInput\x1a\".eolymp.cognito.SelfDestructOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07*\x05/selfB1Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.user_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _USERSERVICE.methods_by_name['CreateUser']._options = None
  _USERSERVICE.methods_by_name['CreateUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\010\"\006/users'
  _USERSERVICE.methods_by_name['VerifyEmail']._options = None
  _USERSERVICE.methods_by_name['VerifyEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\031\"\027/users/{user_id}/verify'
  _USERSERVICE.methods_by_name['ResendEmailVerification']._options = None
  _USERSERVICE.methods_by_name['ResendEmailVerification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002!\"\037/self/email/resend-verification'
  _USERSERVICE.methods_by_name['UpdateProfile']._options = None
  _USERSERVICE.methods_by_name['UpdateProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\007\"\005/self'
  _USERSERVICE.methods_by_name['UpdatePicture']._options = None
  _USERSERVICE.methods_by_name['UpdatePicture']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\017\"\r/self/picture'
  _USERSERVICE.methods_by_name['UpdatePassword']._options = None
  _USERSERVICE.methods_by_name['UpdatePassword']._serialized_options = b'\202\343\n\022\212\343\n\016password_grant\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\020\"\016/self/password'
  _USERSERVICE.methods_by_name['IntrospectUser']._options = None
  _USERSERVICE.methods_by_name['IntrospectUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\007\022\005/self'
  _USERSERVICE.methods_by_name['DescribeUser']._options = None
  _USERSERVICE.methods_by_name['DescribeUser']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\014\365\342\n\000\000HC\370\342\n\364\003\202\323\344\223\002\022\022\020/users/{user_id}'
  _USERSERVICE.methods_by_name['ListUsers']._options = None
  _USERSERVICE.methods_by_name['ListUsers']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\013\365\342\n\000\000pA\370\342\nd\202\323\344\223\002\010\022\006/users'
  _USERSERVICE.methods_by_name['IntrospectQuota']._options = None
  _USERSERVICE.methods_by_name['IntrospectQuota']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/self/quota'
  _USERSERVICE.methods_by_name['StartRecovery']._options = None
  _USERSERVICE.methods_by_name['StartRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\323\344\223\002\020\"\016/self/recovery'
  _USERSERVICE.methods_by_name['CompleteRecovery']._options = None
  _USERSERVICE.methods_by_name['CompleteRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\032\"\030/users/{user_id}/recover'
  _USERSERVICE.methods_by_name['SelfDestruct']._options = None
  _USERSERVICE.methods_by_name['SelfDestruct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\007*\005/self'
  _USERCHANGEDEVENT._serialized_start=275
  _USERCHANGEDEVENT._serialized_end=368
  _CREATEUSERINPUT._serialized_start=371
  _CREATEUSERINPUT._serialized_end=526
  _CREATEUSEROUTPUT._serialized_start=528
  _CREATEUSEROUTPUT._serialized_end=596
  _VERIFYEMAILINPUT._serialized_start=598
  _VERIFYEMAILINPUT._serialized_end=649
  _VERIFYEMAILOUTPUT._serialized_start=651
  _VERIFYEMAILOUTPUT._serialized_end=670
  _RESENDEMAILVERIFICATIONINPUT._serialized_start=672
  _RESENDEMAILVERIFICATIONINPUT._serialized_end=702
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_start=704
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_end=768
  _UPDATEPROFILEINPUT._serialized_start=771
  _UPDATEPROFILEINPUT._serialized_end=1119
  _UPDATEPROFILEINPUT_PATCH._serialized_start=999
  _UPDATEPROFILEINPUT_PATCH._serialized_end=1119
  _UPDATEPROFILEOUTPUT._serialized_start=1121
  _UPDATEPROFILEOUTPUT._serialized_end=1175
  _UPDATEPICTUREINPUT._serialized_start=1177
  _UPDATEPICTUREINPUT._serialized_end=1279
  _UPDATEPICTUREOUTPUT._serialized_start=1281
  _UPDATEPICTUREOUTPUT._serialized_end=1302
  _UPDATEPASSWORDINPUT._serialized_start=1304
  _UPDATEPASSWORDINPUT._serialized_end=1373
  _UPDATEPASSWORDOUTPUT._serialized_start=1375
  _UPDATEPASSWORDOUTPUT._serialized_end=1397
  _INTROSPECTUSERINPUT._serialized_start=1399
  _INTROSPECTUSERINPUT._serialized_end=1420
  _INTROSPECTUSEROUTPUT._serialized_start=1422
  _INTROSPECTUSEROUTPUT._serialized_end=1480
  _DESCRIBEUSERINPUT._serialized_start=1482
  _DESCRIBEUSERINPUT._serialized_end=1518
  _DESCRIBEUSEROUTPUT._serialized_start=1520
  _DESCRIBEUSEROUTPUT._serialized_end=1576
  _LISTUSERSINPUT._serialized_start=1579
  _LISTUSERSINPUT._serialized_end=1789
  _LISTUSERSINPUT_FILTER._serialized_start=1683
  _LISTUSERSINPUT_FILTER._serialized_end=1789
  _LISTUSERSOUTPUT._serialized_start=1791
  _LISTUSERSOUTPUT._serialized_end=1860
  _INTROSPECTQUOTAINPUT._serialized_start=1862
  _INTROSPECTQUOTAINPUT._serialized_end=1884
  _INTROSPECTQUOTAOUTPUT._serialized_start=1887
  _INTROSPECTQUOTAOUTPUT._serialized_end=2120
  _STARTRECOVERYINPUT._serialized_start=2122
  _STARTRECOVERYINPUT._serialized_end=2190
  _STARTRECOVERYOUTPUT._serialized_start=2192
  _STARTRECOVERYOUTPUT._serialized_end=2242
  _COMPLETERECOVERINPUT._serialized_start=2244
  _COMPLETERECOVERINPUT._serialized_end=2317
  _COMPLETERECOVEROUTPUT._serialized_start=2319
  _COMPLETERECOVEROUTPUT._serialized_end=2342
  _SELFDESTRUCTINPUT._serialized_start=2344
  _SELFDESTRUCTINPUT._serialized_end=2363
  _SELFDESTRUCTOUTPUT._serialized_start=2365
  _SELFDESTRUCTOUTPUT._serialized_end=2432
  _USERSERVICE._serialized_start=2435
  _USERSERVICE._serialized_end=4212
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Assignment(_message.Message):
    __slots__ = ["complete_before", "duration", "group_id", "id", "member_id", "module_id", "start_after", "status", "upsolve"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: Assignment.Status
    COMPLETE: Assignment.Status
    COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    READY: Assignment.Status
    SCHEDULED: Assignment.Status
    START_AFTER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UNASSIGNED: Assignment.Status
    UNKNOWN_STATUS: Assignment.Status
    UPSOLVE: Assignment.Status
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    complete_before: _timestamp_pb2.Timestamp
    duration: int
    group_id: str
    id: str
    member_id: str
    module_id: str
    start_after: _timestamp_pb2.Timestamp
    status: Assignment.Status
    upsolve: bool
    def __init__(self, id: _Optional[str] = ..., module_id: _Optional[str] = ..., status: _Optional[_Union[Assignment.Status, str]] = ..., member_id: _Optional[str] = ..., group_id: _Optional[str] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., upsolve: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2
from eolymp.ecm import node_pb2 as eolymp_dot_ecm_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/judge/problem.proto\x12\x0c\x65olymp.judge\x1a#eolymp/atlas/testing_feedback.proto\x1a\x15\x65olymp/ecm/node.proto\"\xd3\x04\n\x07Problem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x0f\n\x07\x62\x61se_id\x18\x04 \x01(\t\x12\x13\n\x0b\x62\x61se_number\x18- \x01(\r\x12\x15\n\rbase_space_id\x18( \x01(\t\x12\x12\n\ncontest_id\x18\x05 \x01(\t\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\n \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy\x12\x13\n\ntime_limit\x18\xc8\x01 \x01(\r\x12\x12\n\tcpu_limit\x18\xcc\x01 \x01(\r\x12\x15\n\x0cmemory_limit\x18\xc9\x01 \x01(\x04\x12\x18\n\x0f\x66ile_size_limit\x18\xca\x01 \x01(\x04\x12\x15\n\x0csubmit_limit\x18\xcb\x01 \x01(\r\x12\x1e\n\x15score_by_best_testset\x18\xd2\x01 \x01(\x08\x1a\x64\n\tStatement\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12!\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x10.eolymp.ecm.Node\x12\x15\n\rdownload_link\x18\x06 \x01(\t\x1a\\\n\x04Test\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0f\n\x07\x65xample\x18\x02 \x01(\x08\x12\x11\n\tinput_url\x18\r \x01(\t\x12\x12\n\nanswer_url\x18\x0e \x01(\t\x12\r\n\x05score\x18\x05 \x01(\x02\x1a\x34\n\nAttachment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04link\x18\x04 \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.problem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _PROBLEM._serialized_start=105
  _PROBLEM._serialized_end=700
  _PROBLEM_STATEMENT._serialized_start=452
  _PROBLEM_STATEMENT._serialized_end=552
  _PROBLEM_TEST._serialized_start=554
  _PROBLEM_TEST._serialized_end=646
  _PROBLEM_ATTACHMENT._serialized_start=648
  _PROBLEM_ATTACHMENT._serialized_end=700
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/cognito.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.cognito import access_key_service_pb2 as eolymp_dot_cognito_dot_access__key__service__pb2
from eolymp.cognito import user_service_pb2 as eolymp_dot_cognito_dot_user__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/cognito/cognito.proto\x12\x0e\x65olymp.cognito\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\'eolymp/cognito/access_key_service.proto\x1a!eolymp/cognito/user_service.proto2\xe4\x11\n\x07\x43ognito\x12\xa3\x01\n\x0f\x43reateAccessKey\x12$.eolymp.cognito.CreateAccessKeyInput\x1a%.eolymp.cognito.CreateAccessKeyOutput\"C\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ognito:access-key:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0e\"\x0c/access-keys\x12\xac\x01\n\x0f\x44\x65leteAccessKey\x12$.eolymp.cognito.DeleteAccessKeyInput\x1a%.eolymp.cognito.DeleteAccessKeyOutput\"L\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ognito:access-key:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17*\x15/access-keys/{key_id}\x12\x9f\x01\n\x0eListAccessKeys\x12#.eolymp.cognito.ListAccessKeysInput\x1a$.eolymp.cognito.ListAccessKeysOutput\"B\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ognito:access-key:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/access-keys\x12n\n\nCreateUser\x12\x1f.eolymp.cognito.CreateUserInput\x1a .eolymp.cognito.CreateUserOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x08\"\x06/users\x12\x82\x01\n\x0bVerifyEmail\x12 .eolymp.cognito.VerifyEmailInput\x1a!.eolymp.cognito.VerifyEmailOutput\".\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\x19\"\x17/users/{user_id}/verify\x12\xae\x01\n\x17ResendEmailVerification\x12,.eolymp.cognito.ResendEmailVerificationInput\x1a-.eolymp.cognito.ResendEmailVerificationOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!\"\x1f/self/email/resend-verification\x12v\n\rUpdateProfile\x12\".eolymp.cognito.UpdateProfileInput\x1a#.eolymp.cognito.UpdateProfileOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/self\x12~\n\rUpdatePicture\x12\".eolymp.cognito.UpdatePictureInput\x1a#.eolymp.cognito.UpdatePictureOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0f\"\r/self/picture\x12\x98\x01\n\x0eUpdatePassword\x12#.eolymp.cognito.UpdatePasswordInput\x1a$.eolymp.cognito.UpdatePasswordOutput\";\x82\xe3\n\x12\x8a\xe3\n\x0epassword_grant\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/password\x12y\n\x0eIntrospectUser\x12#.eolymp.cognito.IntrospectUserInput\x1a$.eolymp.cognito.IntrospectUserOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x07\x12\x05/self\x12\x98\x01\n\x0c\x44\x65scribeUser\x12!.eolymp.cognito.DescribeUserInput\x1a\".eolymp.cognito.DescribeUserOutput\"A\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HC\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x12\x12\x10/users/{user_id}\x12\x84\x01\n\tListUsers\x12\x1e.eolymp.cognito.ListUsersInput\x1a\x1f.eolymp.cognito.ListUsersOutput\"6\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00pA\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/users\x12\x82\x01\n\x0fIntrospectQuota\x12$.eolymp.cognito.IntrospectQuotaInput\x1a%.eolymp.cognito.IntrospectQuotaOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/self/quota\x12\x7f\n\rStartRecovery\x12\".eolymp.cognito.StartRecoveryInput\x1a#.eolymp.cognito.StartRecoveryOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/recovery\x12\x90\x01\n\x10\x43ompleteRecovery\x12$.eolymp.cognito.CompleteRecoverInput\x1a%.eolymp.cognito.CompleteRecoverOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1a\"\x18/users/{user_id}/recover\x12s\n\x0cSelfDestruct\x12!.eolymp.cognito.SelfDestructInput\x1a\".eolymp.cognito.SelfDestructOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07*\x05/selfB1Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.cognito_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _COGNITO.methods_by_name['CreateAccessKey']._options = None
  _COGNITO.methods_by_name['CreateAccessKey']._serialized_options = b'\202\343\n\034\212\343\n\030cognito:access-key:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\016\"\014/access-keys'
  _COGNITO.methods_by_name['DeleteAccessKey']._options = None
  _COGNITO.methods_by_name['DeleteAccessKey']._serialized_options = b'\202\343\n\034\212\343\n\030cognito:access-key:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027*\025/access-keys/{key_id}'
  _COGNITO.methods_by_name['ListAccessKeys']._options = None
  _COGNITO.methods_by_name['ListAccessKeys']._serialized_options = b'\202\343\n\033\212\343\n\027cognito:access-key:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/access-keys'
  _COGNITO.methods_by_name['CreateUser']._options = None
  _COGNITO.methods_by_name['CreateUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\010\"\006/users'
  _COGNITO.methods_by_name['VerifyEmail']._options = None
  _COGNITO.methods_by_name['VerifyEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\031\"\027/users/{user_id}/verify'
  _COGNITO.methods_by_name['ResendEmailVerification']._options = None
  _COGNITO.methods_by_name['ResendEmailVerification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002!\"\037/self/email/resend-verification'
  _COGNITO.methods_by_name['UpdateProfile']._options = None
  _COGNITO.methods_by_name['UpdateProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\007\"\005/self'
  _COGNITO.methods_by_name['UpdatePicture']._options = None
  _COGNITO.methods_by_name['UpdatePicture']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\017\"\r/self/picture'
  _COGNITO.methods_by_name['UpdatePassword']._options = None
  _COGNITO.methods_by_name['UpdatePassword']._serialized_options = b'\202\343\n\022\212\343\n\016password_grant\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\020\"\016/self/password'
  _COGNITO.methods_by_name['IntrospectUser']._options = None
  _COGNITO.methods_by_name['IntrospectUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\007\022\005/self'
  _COGNITO.methods_by_name['DescribeUser']._options = None
  _COGNITO.methods_by_name['DescribeUser']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\014\365\342\n\000\000HC\370\342\n\364\003\202\323\344\223\002\022\022\020/users/{user_id}'
  _COGNITO.methods_by_name['ListUsers']._options = None
  _COGNITO.methods_by_name['ListUsers']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\013\365\342\n\000\000pA\370\342\nd\202\323\344\223\002\010\022\006/users'
  _COGNITO.methods_by_name['IntrospectQuota']._options = None
  _COGNITO.methods_by_name['IntrospectQuota']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/self/quota'
  _COGNITO.methods_by_name['StartRecovery']._options = None
  _COGNITO.methods_by_name['StartRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\323\344\223\002\020\"\016/self/recovery'
  _COGNITO.methods_by_name['CompleteRecovery']._options = None
  _COGNITO.methods_by_name['CompleteRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\032\"\030/users/{user_id}/recover'
  _COGNITO.methods_by_name['SelfDestruct']._options = None
  _COGNITO.methods_by_name['SelfDestruct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\007*\005/self'
  _COGNITO._serialized_start=224
  _COGNITO._serialized_end=2500
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/contest_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import activity_pb2 as eolymp_dot_judge_dot_activity__pb2
from eolymp.judge import contest_pb2 as eolymp_dot_judge_dot_contest__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/judge/contest_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/judge/activity.proto\x1a\x1a\x65olymp/judge/contest.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x12\x43reateContestInput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\")\n\x13\x43reateContestOutput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteContestOutput\"\xcb\x03\n\x12UpdateContestInput\x12\x35\n\x05patch\x18\x03 \x03(\x0e\x32&.eolymp.judge.UpdateContestInput.Patch\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12&\n\x07\x63ontest\x18\x02 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\xc1\x02\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x02\x12\r\n\tSTARTS_AT\x10\x03\x12\x0b\n\x07\x45NDS_AT\x10\x04\x12\x0c\n\x08\x44URATION\x10\x05\x12\x0e\n\nVISIBILITY\x10\x06\x12\x15\n\x11JOIN_UNOFFICIALLY\x10\x07\x12\x16\n\x12PARTICIPATION_MODE\x10\x08\x12\n\n\x06\x46ORMAT\x10\n\x12\x07\n\x03KEY\x10\x0b\x12\x0c\n\x08LOGO_URL\x10\x0e\x12\x18\n\x14PROBLEM_COUNT_HIDDEN\x10\x0c\x12\x1c\n\x18PARTICIPANT_COUNT_HIDDEN\x10\r\x12\x12\n\x0e\x46\x45\x41TURED_UNTIL\x10\t\x12\r\n\x08TAXONOMY\x10\x8c\x01\x12\x0e\n\nAPPEARANCE\x10n\x12\x10\n\x0b\x45NVIRONMENT\x10\x82\x01\x12\x0b\n\x07UPSOLVE\x10x\x12\x0f\n\nSCOREBOARD\x10\x96\x01\"\x15\n\x13UpdateContestOutput\"\x84\x02\n\x10\x43opyContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x38\n\ncopy_scope\x18\x02 \x03(\x0e\x32$.eolymp.judge.CopyContestInput.Scope\x12\x11\n\tcopy_name\x18\x03 \x01(\t\x12\x39\n\x0f\x63opy_visibility\x18\x04 \x01(\x0e\x32 .eolymp.judge.Contest.Visibility\"T\n\x05Scope\x12\x07\n\x03\x41LL\x10\x00\x12\x11\n\rCONFIGURATION\x10\x01\x12\x0c\n\x08PROBLEMS\x10\x02\x12\x10\n\x0cPARTICIPANTS\x10\x03\x12\x0f\n\x0bPERMISSIONS\x10\x04\",\n\x11\x43opyContestOutput\x12\x17\n\x0f\x63opy_contest_id\x18\x01 \x01(\t\"*\n\x14\x44\x65scribeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\xb2\x07\n\x11ListContestsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.judge.ListContestsInput.Filter\x1a\xc5\x06\n\x06\x46ilter\x12\r\n\x05query\x18\t \x01(\t\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\tstarts_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x36\n\x07\x65nds_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06public\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nvisibility\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06\x66ormat\x18\x08 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x32\n\x08\x66\x65\x61tured\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x04year\x18\x64 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12/\n\x05scale\x18\x65 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06series\x18\x66 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x33\n\ndifficulty\x18g \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x31\n\x07\x63ountry\x18h \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06region\x18i \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x04\x63ity\x18j \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"I\n\x12ListContestsOutput\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.eolymp.judge.Contest\x12\r\n\x05total\x18\x02 \x01(\x05\"&\n\x10OpenContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11OpenContestOutput\"\'\n\x11\x43loseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12\x43loseContestOutput\")\n\x13SuspendContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x16\n\x14SuspendContestOutput\"(\n\x12\x46reezeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x46reezeContestOutput\"(\n\x12ResumeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13ResumeContestOutput\"\'\n\x11WatchContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"<\n\x12WatchContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"G\n\x13ListActivitiesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"L\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.judge.Activity\"}\n\x19\x44\x65scribeContestUsageInput\x12\x30\n\x0cperiod_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nperiod_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"g\n\x1a\x44\x65scribeContestUsageOutput\x12\x16\n\x0etotal_contests\x18\x01 \x01(\r\x12\x17\n\x0f\x61\x63tive_contests\x18\x02 \x01(\r\x12\x18\n\x10monthly_contests\x18\x03 \x01(\r2\xfa\x10\n\x0e\x43ontestService\x12\x91\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7\xa3=\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0b\"\t/contests\x12\x9e\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18*\x16/contests/{contest_id}\x12\x9e\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\x1a\x16/contests/{contest_id}\x12\x9d\x01\n\x0b\x43opyContest\x12\x1e.eolymp.judge.CopyContestInput\x1a\x1f.eolymp.judge.CopyContestOutput\"M\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/copy\x12\x89\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x12\x16/contests/{contest_id}\x12s\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\x12\t/contests\x12\x9d\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"M\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/open\x12\xa1\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/close\x12\xa9\x01\n\x0eSuspendContest\x12!.eolymp.judge.SuspendContestInput\x1a\".eolymp.judge.SuspendContestOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/suspend\x12\xa5\x01\n\rFreezeContest\x12 .eolymp.judge.FreezeContestInput\x1a!.eolymp.judge.FreezeContestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/freeze\x12\xa5\x01\n\rResumeContest\x12 .eolymp.judge.ResumeContestInput\x1a!.eolymp.judge.ResumeContestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/resume\x12o\n\x0cWatchContest\x12\x1f.eolymp.judge.WatchContestInput\x1a .eolymp.judge.WatchContestOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xab\x01\n\x0eListActivities\x12!.eolymp.judge.ListActivitiesInput\x1a\".eolymp.judge.ListActivitiesOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/activities\x12\x91\x01\n\x14\x44\x65scribeContestUsage\x12\'.eolymp.judge.DescribeContestUsageInput\x1a(.eolymp.judge.DescribeContestUsageOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\x12\x0f/usage/contestsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.contest_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _CONTESTSERVICE.methods_by_name['CreateContest']._options = None
  _CONTESTSERVICE.methods_by_name['CreateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327\243=\370\342\n\005\202\323\344\223\002\013\"\t/contests'
  _CONTESTSERVICE.methods_by_name['DeleteContest']._options = None
  _CONTESTSERVICE.methods_by_name['DeleteContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030*\026/contests/{contest_id}'
  _CONTESTSERVICE.methods_by_name['UpdateContest']._options = None
  _CONTESTSERVICE.methods_by_name['UpdateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030\032\026/contests/{contest_id}'
  _CONTESTSERVICE.methods_by_name['CopyContest']._options = None
  _CONTESTSERVICE.methods_by_name['CopyContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\"\033/contests/{contest_id}/copy'
  _CONTESTSERVICE.methods_by_name['DescribeContest']._options = None
  _CONTESTSERVICE.methods_by_name['DescribeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\030\022\026/contests/{contest_id}'
  _CONTESTSERVICE.methods_by_name['ListContests']._options = None
  _CONTESTSERVICE.methods_by_name['ListContests']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\013\022\t/contests'
  _CONTESTSERVICE.methods_by_name['OpenContest']._options = None
  _CONTESTSERVICE.methods_by_name['OpenContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\"\033/contests/{contest_id}/open'
  _CONTESTSERVICE.methods_by_name['CloseContest']._options = None
  _CONTESTSERVICE.methods_by_name['CloseContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\"\034/contests/{contest_id}/close'
  _CONTESTSERVICE.methods_by_name['SuspendContest']._options = None
  _CONTESTSERVICE.methods_by_name['SuspendContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002 \"\036/contests/{contest_id}/suspend'
  _CONTESTSERVICE.methods_by_name['FreezeContest']._options = None
  _CONTESTSERVICE.methods_by_name['FreezeContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/contests/{contest_id}/freeze'
  _CONTESTSERVICE.methods_by_name['ResumeContest']._options = None
  _CONTESTSERVICE.methods_by_name['ResumeContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/contests/{contest_id}/resume'
  _CONTESTSERVICE.methods_by_name['WatchContest']._options = None
  _CONTESTSERVICE.methods_by_name['WatchContest']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _CONTESTSERVICE.methods_by_name['ListActivities']._options = None
  _CONTESTSERVICE.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002#\022!/contests/{contest_id}/activities'
  _CONTESTSERVICE.methods_by_name['DescribeContestUsage']._options = None
  _CONTESTSERVICE.methods_by_name['DescribeContestUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\021\022\017/usage/contests'
  _CREATECONTESTINPUT._serialized_start=276
  _CREATECONTESTINPUT._serialized_end=336
  _CREATECONTESTOUTPUT._serialized_start=338
  _CREATECONTESTOUTPUT._serialized_end=379
  _DELETECONTESTINPUT._serialized_start=381
  _DELETECONTESTINPUT._serialized_end=421
  _DELETECONTESTOUTPUT._serialized_start=423
  _DELETECONTESTOUTPUT._serialized_end=444
  _UPDATECONTESTINPUT._serialized_start=447
  _UPDATECONTESTINPUT._serialized_end=906
  _UPDATECONTESTINPUT_PATCH._serialized_start=585
  _UPDATECONTESTINPUT_PATCH._serialized_end=906
  _UPDATECONTESTOUTPUT._serialized_start=908
  _UPDATECONTESTOUTPUT._serialized_end=929
  _COPYCONTESTINPUT._serialized_start=932
  _COPYCONTESTINPUT._serialized_end=1192
  _COPYCONTESTINPUT_SCOPE._serialized_start=1108
  _COPYCONTESTINPUT_SCOPE._serialized_end=1192
  _COPYCONTESTOUTPUT._serialized_start=1194
  _COPYCONTESTOUTPUT._serialized_end=1238
  _DESCRIBECONTESTINPUT._serialized_start=1240
  _DESCRIBECONTESTINPUT._serialized_end=1282
  _DESCRIBECONTESTOUTPUT._serialized_start=1284
  _DESCRIBECONTESTOUTPUT._serialized_end=1347
  _LISTCONTESTSINPUT._serialized_start=1350
  _LISTCONTESTSINPUT._serialized_end=2296
  _LISTCONTESTSINPUT_FILTER._serialized_start=1459
  _LISTCONTESTSINPUT_FILTER._serialized_end=2296
  _LISTCONTESTSOUTPUT._serialized_start=2298
  _LISTCONTESTSOUTPUT._serialized_end=2371
  _OPENCONTESTINPUT._serialized_start=2373
  _OPENCONTESTINPUT._serialized_end=2411
  _OPENCONTESTOUTPUT._serialized_start=2413
  _OPENCONTESTOUTPUT._serialized_end=2432
  _CLOSECONTESTINPUT._serialized_start=2434
  _CLOSECONTESTINPUT._serialized_end=2473
  _CLOSECONTESTOUTPUT._serialized_start=2475
  _CLOSECONTESTOUTPUT._serialized_end=2495
  _SUSPENDCONTESTINPUT._serialized_start=2497
  _SUSPENDCONTESTINPUT._serialized_end=2538
  _SUSPENDCONTESTOUTPUT._serialized_start=2540
  _SUSPENDCONTESTOUTPUT._serialized_end=2562
  _FREEZECONTESTINPUT._serialized_start=2564
  _FREEZECONTESTINPUT._serialized_end=2604
  _FREEZECONTESTOUTPUT._serialized_start=2606
  _FREEZECONTESTOUTPUT._serialized_end=2627
  _RESUMECONTESTINPUT._serialized_start=2629
  _RESUMECONTESTINPUT._serialized_end=2669
  _RESUMECONTESTOUTPUT._serialized_start=2671
  _RESUMECONTESTOUTPUT._serialized_end=2692
  _WATCHCONTESTINPUT._serialized_start=2694
  _WATCHCONTESTINPUT._serialized_end=2733
  _WATCHCONTESTOUTPUT._serialized_start=2735
  _WATCHCONTESTOUTPUT._serialized_end=2795
  _LISTACTIVITIESINPUT._serialized_start=2797
  _LISTACTIVITIESINPUT._serialized_end=2868
  _LISTACTIVITIESOUTPUT._serialized_start=2870
  _LISTACTIVITIESOUTPUT._serialized_end=2946
  _DESCRIBECONTESTUSAGEINPUT._serialized_start=2948
  _DESCRIBECONTESTUSAGEINPUT._serialized_end=3073
  _DESCRIBECONTESTUSAGEOUTPUT._serialized_start=3075
  _DESCRIBECONTESTUSAGEOUTPUT._serialized_end=3178
  _CONTESTSERVICE._serialized_start=3181
  _CONTESTSERVICE._serialized_end=5351
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

COMPLETE: FeedbackPolicy
DESCRIPTOR: _descriptor.FileDescriptor
ICPC: FeedbackPolicy
ICPC_EXPANDED: FeedbackPolicy

class FeedbackPolicy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import attribute_pb2 as _attribute_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAttributeInput(_message.Message):
    __slots__ = ["attribute", "attribute_key"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute: _attribute_pb2.Attribute
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ..., attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class CreateAttributeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeAttributeInput(_message.Message):
    __slots__ = ["attribute_key"]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ...) -> None: ...

class DescribeAttributeOutput(_message.Message):
    __slots__ = ["attribute"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    attribute: _attribute_pb2.Attribute
    def __init__(self, attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class ListAttributesInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["hidden", "id", "key", "required", "type"]
        HIDDEN_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        REQUIRED_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        hidden: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        key: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        required: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., key: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., hidden: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., required: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListAttributesInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListAttributesInput.Filter, _Mapping]] = ...) -> None: ...

class ListAttributesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_attribute_pb2.Attribute, _Mapping]]] = ...) -> None: ...

class RemoveAttributeInput(_message.Message):
    __slots__ = ["attribute_key"]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ...) -> None: ...

class RemoveAttributeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateAttributeInput(_message.Message):
    __slots__ = ["attribute", "attribute_key"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute: _attribute_pb2.Attribute
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ..., attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class UpdateAttributeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Term(_message.Message):
    __slots__ = ["description", "id", "key", "message", "status"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: Term.Status
    DEPRECATED: Term.Status
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    NONE: Term.Status
    STATUS_FIELD_NUMBER: _ClassVar[int]
    description: str
    id: str
    key: str
    message: str
    status: Term.Status
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., message: _Optional[str] = ..., description: _Optional[str] = ..., status: _Optional[_Union[Term.Status, str]] = ...) -> None: ...
